@@ -4,6 +4,7 @@ TenantId = TypeVar('TenantId', bound=str)
 
 DataSourceId = TypeVar('DataSourceId', bound=str)
 ExternalWriterId = TypeVar('ExternalWriterId', bound=str)
+PluginId = TypeVar('PluginId', bound=str)
 
 UserId = TypeVar('UserId', bound=str)
 UserGroupId = TypeVar('UserGroupId', bound=str)
@@ -31,6 +32,7 @@ IndicatorId = TypeVar('IndicatorId', bound=str)
 InspectionId = TypeVar('InspectionId', bound=str)
 AchievementId = TypeVar('AchievementId', bound=str)
 ObjectiveAnalysisId = TypeVar('ObjectiveAnalysisId', bound=str)
+AchievementPluginTaskId = TypeVar('AchievementPluginTaskId', bound=str)
 
 PatId = TypeVar('PatId', bound=str)
 
